@@ -13,7 +13,6 @@
 
 #include "triggers/gestures.h"
 
-
 #include <QDebug>
 #include <kglobalaccel.h>
 #include <kpluginfactory.h>
@@ -23,171 +22,146 @@
 
 #define COMPONENT_NAME "khotkeys"
 
-K_PLUGIN_FACTORY_WITH_JSON(KHotKeysModuleFactory,
-                           "khotkeys.json",
-                           registerPlugin<KHotKeysModule>();)
+K_PLUGIN_FACTORY_WITH_JSON(KHotKeysModuleFactory, "khotkeys.json", registerPlugin<KHotKeysModule>();)
 
 using namespace KHotKeys;
 
 // KhotKeysModule
 
-KHotKeysModule::KHotKeysModule(QObject* parent, const QList<QVariant>&)
+KHotKeysModule::KHotKeysModule(QObject *parent, const QList<QVariant> &)
     : KDEDModule(parent)
     , actions_root(nullptr)
     , _settingsDirty(false)
     , _settings()
-    ,_initialized(false)
-    {
+    , _initialized(false)
+{
     // initialize
     qDebug() << "Installing the delayed initialization callback.";
-    QMetaObject::invokeMethod( this, "initialize", Qt::QueuedConnection);
-    }
-
+    QMetaObject::invokeMethod(this, "initialize", Qt::QueuedConnection);
+}
 
 void KHotKeysModule::initialize()
-    {
-    if (_initialized)
-        {
+{
+    if (_initialized) {
         return;
-        }
+    }
 
     qDebug() << "Delayed initialization.";
     _initialized = true;
 
     // Initialize the global data, grab keys
-    KHotKeys::init_global_data( true, this );
+    KHotKeys::init_global_data(true, this);
 
     // If a shortcut was changed (global shortcuts kcm), save
-    connect(
-            keyboard_handler.data(), SIGNAL(shortcutChanged()),
-            this, SLOT(scheduleSave()));
+    connect(keyboard_handler.data(), SIGNAL(shortcutChanged()), this, SLOT(scheduleSave()));
 
     // Read the configuration from file khotkeysrc
     reread_configuration();
 
     KGlobalAccel::cleanComponent(COMPONENT_NAME);
 
-    if (_settings.update())
-        {
+    if (_settings.update()) {
         save();
-        }
-
     }
-
+}
 
 KHotKeysModule::~KHotKeysModule()
-    {
+{
     // actions_root belongs to _settings.
     actions_root = nullptr;
-    }
-
+}
 
 void KHotKeysModule::reread_configuration()
-    {
+{
     qDebug() << "Reloading the khotkeys configuration";
 
     // Stop listening
     actions_root = nullptr; // Disables the dbus interface effectively
-    KHotKeys::khotkeys_set_active( false );
+    KHotKeys::khotkeys_set_active(false);
 
     // Load the settings
     _settings.reread_settings(true);
 
-    KHotKeys::gesture_handler->set_mouse_button( _settings.gestureMouseButton() );
-    KHotKeys::gesture_handler->set_timeout( _settings.gestureTimeOut() );
+    KHotKeys::gesture_handler->set_mouse_button(_settings.gestureMouseButton());
+    KHotKeys::gesture_handler->set_timeout(_settings.gestureTimeOut());
     qDebug() << _settings.areGesturesDisabled();
-    KHotKeys::gesture_handler->enable( !_settings.areGesturesDisabled() );
-    KHotKeys::gesture_handler->set_exclude( _settings.gesturesExclude() );
+    KHotKeys::gesture_handler->enable(!_settings.areGesturesDisabled());
+    KHotKeys::gesture_handler->set_exclude(_settings.gesturesExclude());
     // FIXME: SOUND
     // KHotKeys::voice_handler->set_shortcut( _settings.voice_shortcut );
     actions_root = _settings.actions();
-    KHotKeys::khotkeys_set_active( true );
-    }
+    KHotKeys::khotkeys_set_active(true);
+}
 
-
-
-
-SimpleActionData* KHotKeysModule::menuentry_action(const QString &storageId)
-    {
-    ActionDataGroup *menuentries = _settings.get_system_group(
-            ActionDataGroup::SYSTEM_MENUENTRIES);
+SimpleActionData *KHotKeysModule::menuentry_action(const QString &storageId)
+{
+    ActionDataGroup *menuentries = _settings.get_system_group(ActionDataGroup::SYSTEM_MENUENTRIES);
 
     // Now try to find the action
-    Q_FOREACH(ActionDataBase* element, menuentries->children())
-        {
-        SimpleActionData *actionData = dynamic_cast<SimpleActionData*>(element);
+    Q_FOREACH (ActionDataBase *element, menuentries->children()) {
+        SimpleActionData *actionData = dynamic_cast<SimpleActionData *>(element);
 
-        if (actionData && actionData->action())
-            {
-            MenuEntryAction *action = dynamic_cast<MenuEntryAction*>(actionData->action());
-            if (action && action->service() && (action->service()->storageId() == storageId))
-                {
+        if (actionData && actionData->action()) {
+            MenuEntryAction *action = dynamic_cast<MenuEntryAction *>(actionData->action());
+            if (action && action->service() && (action->service()->storageId() == storageId)) {
                 return actionData;
-                }
             }
         }
-
-    return nullptr;
     }
 
+    return nullptr;
+}
 
 QString KHotKeysModule::get_menuentry_shortcut(const QString &storageId)
-    {
-    SimpleActionData* actionData = menuentry_action(storageId);
+{
+    SimpleActionData *actionData = menuentry_action(storageId);
 
     // No action found
-    if (actionData == nullptr) return "";
+    if (actionData == nullptr)
+        return "";
 
     // The action must have a shortcut trigger. but don't assume to much
-    ShortcutTrigger* shortcutTrigger = dynamic_cast<ShortcutTrigger*>(actionData->trigger());
+    ShortcutTrigger *shortcutTrigger = dynamic_cast<ShortcutTrigger *>(actionData->trigger());
 
     Q_ASSERT(shortcutTrigger);
-    if (shortcutTrigger == nullptr) return "";
+    if (shortcutTrigger == nullptr)
+        return "";
 
     qDebug() << shortcutTrigger->primaryShortcut();
 
     return shortcutTrigger->primaryShortcut();
-    }
+}
 
-
-QString KHotKeysModule::register_menuentry_shortcut(
-        const QString &storageId,
-        const QString &sequence)
-    {
+QString KHotKeysModule::register_menuentry_shortcut(const QString &storageId, const QString &sequence)
+{
     qDebug() << storageId << "(" << sequence << ")";
 
     // Check the service we got. If it is invalid there is no need to
     // continue.
     KService::Ptr wantedService = KService::serviceByStorageId(storageId);
-    if (!wantedService)
-        {
+    if (!wantedService) {
         qCritical() << "Storage Id " << storageId << "not valid";
         return "";
-        }
+    }
 
     // Look for the action
-    SimpleActionData* actionData = menuentry_action(storageId);
+    SimpleActionData *actionData = menuentry_action(storageId);
 
     // No action found. Create on if sequence is != ""
-    if (actionData == nullptr)
-        {
+    if (actionData == nullptr) {
         qDebug() << "No action found";
 
         // If the sequence is empty there is no need to create a action.
-        if (sequence.isEmpty()) return "";
+        if (sequence.isEmpty())
+            return "";
 
         qDebug() << "Creating a new action";
 
         // Create the action
-        ActionDataGroup *menuentries = _settings.get_system_group(
-                ActionDataGroup::SYSTEM_MENUENTRIES);
+        ActionDataGroup *menuentries = _settings.get_system_group(ActionDataGroup::SYSTEM_MENUENTRIES);
 
-        MenuEntryShortcutActionData *newAction = new MenuEntryShortcutActionData(
-                menuentries,
-                wantedService->name(),
-                storageId,
-                QKeySequence(sequence),
-                storageId);
+        MenuEntryShortcutActionData *newAction =
+            new MenuEntryShortcutActionData(menuentries, wantedService->name(), storageId, QKeySequence(sequence), storageId);
 
         newAction->enable();
 
@@ -195,26 +169,22 @@ QString KHotKeysModule::register_menuentry_shortcut(
 
         // Return the real shortcut
         return newAction->trigger()->primaryShortcut();
-        }
+    }
     // We found a action
-    else
-        {
-        if (sequence.isEmpty())
-            {
+    else {
+        if (sequence.isEmpty()) {
             qDebug() << "Deleting the action";
             actionData->aboutToBeErased();
             delete actionData;
             _settings.write();
             return "";
-            }
-        else
-            {
+        } else {
             qDebug() << "Changing the action";
             // The action must have a shortcut trigger. but don't assume to much
-            ShortcutTrigger* shortcutTrigger =
-                    dynamic_cast<ShortcutTrigger*>(actionData->trigger());
+            ShortcutTrigger *shortcutTrigger = dynamic_cast<ShortcutTrigger *>(actionData->trigger());
             Q_ASSERT(shortcutTrigger);
-            if (shortcutTrigger == nullptr) return "";
+            if (shortcutTrigger == nullptr)
+                return "";
 
             // Change the actionData
             shortcutTrigger->set_key_sequence(sequence);
@@ -222,39 +192,37 @@ QString KHotKeysModule::register_menuentry_shortcut(
 
             // Remove the resulting real shortcut
             return shortcutTrigger->primaryShortcut();
-            }
         }
+    }
 
     Q_ASSERT(false);
     return "";
-    }
-
+}
 
 void KHotKeysModule::quit()
-    {
+{
     deleteLater();
-    }
+}
 
 void KHotKeysModule::scheduleSave()
-    {
-    if (!_settingsDirty)
-        {
+{
+    if (!_settingsDirty) {
         _settingsDirty = true;
         QMetaObject::invokeMethod(this, "save", Qt::QueuedConnection);
-        }
     }
+}
 
 void KHotKeysModule::save()
-    {
+{
     _settingsDirty = false;
-    KHotKeys::khotkeys_set_active( false );
+    KHotKeys::khotkeys_set_active(false);
     _settings.write();
-    KHotKeys::khotkeys_set_active( true );
-    }
+    KHotKeys::khotkeys_set_active(true);
+}
 
 void KHotKeysModule::declareConfigOutdated()
-    {
+{
     Settings::isOutdated = true;
-    }
+}
 
 #include "kded.moc"
